summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyselector.h')
-rw-r--r--kmymoney2/widgets/kmymoneyselector.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmymoney2/widgets/kmymoneyselector.h b/kmymoney2/widgets/kmymoneyselector.h
index c55ac47..a0facf0 100644
--- a/kmymoney2/widgets/kmymoneyselector.h
+++ b/kmymoney2/widgets/kmymoneyselector.h
@@ -262,14 +262,14 @@ public:
TQListViewItem* item(const TQString& id) const;
/**
* This method returns, if any of the items in the selector tqcontains
* the text @a txt.
*
* @param txt const reference to string to be looked for
* @retval true exact match found
* @retval false no match found
*/
- virtual bool tqcontains(const TQString& txt) const;
+ virtual bool contains(const TQString& txt) const;
/**
* Clears all items of the selector and the associated listview.
@@ -262,14 +262,14 @@ public:
TQListViewItem* item(const TQString& id) const;
/**
- * This method returns, if any of the items in the selector tqcontains
+ * This method returns, if any of the items in the selector contains
* the text @a txt.
*